@@ -1,14 +1,18 @@
-import time
-LogerLevel = 4
-LogerTimeMark = False
-LogerColor = True
-LogerOutputFile = None
-
-# None     0
+"""[
+        # None     0
 # Ero      1
 # War      2
 # Inf      3
 # Suc      4
+    ]
+    """
+
+import time
+
+SHOWLEVEL = 4
+TIMEMARK = False
+COLOR = True
+FILEPATH = ""
 
 levelTag = {
     'nocolor': {
@@ -26,30 +30,30 @@ levelTag = {
 }
 
 
-def setting(logerLevel=4, logerTimeMark=False, logerColor=True, logerOutputFile=None):
-    global LogerLevel, LogerColor, LogerOutputFile, LogerTimeMark
+def loger_setting(show_level: int = 4, time_mark: bool = False, color: bool = True, file_path: str = ""):
 
-    LogerLevel = logerLevel
-    LogerTimeMark = logerTimeMark
-    LogerColor = logerColor
-    LogerOutputFile = logerOutputFile
+    global SHOWLEVEL,TIMEMARK,COLOR,FILEPATH
 
+    SHOWLEVEL = show_level
+    TIMEMARK = time_mark
+    COLOR = color
+    FILEPATH = file_path
 
-def makelog(log: str, level: int = 3):
-    if level <= LogerLevel:
-        if LogerTimeMark:
+def log(log: str, level: int = 3):
+    if level <= SHOWLEVEL:
+        if TIMEMARK:
             log = time.strftime("%Y-%m-%d %H:%M:%S",
                                 time.localtime()) + '>' + log
-        
 
-        if LogerOutputFile != None:
-            with open(LogerOutputFile, 'a') as f:
+        if FILEPATH:
+            with open(FILEPATH, 'a') as f:
                 f.write(levelTag['nocolor'][level]+log+'\n')
 
-        if LogerColor:
+        if COLOR:
             log = levelTag['color'][level] + log
         else:
             log = levelTag['nocolor'][level]+log
 
         print(log)
 
+
